==> fluidpythran-0.0.7.tar.gz: fluidpythran-0.0.7/data_tests/class_blocks.py <==
import numpy as np

# pythran import numpy as np

# pythran blabla

from fluidpythran import FluidPythran

fp = FluidPythran()


class MyClass:
    def __init__(self, a, b):
        self.a = a
        self.b = b

    def compute(self, n):

        a = self.a
        b = self.b

        if fp.is_pythranized:
            result = fp.use_pythranized_block("block0")
        else:
            # pythran block (
            #     float[][] a, b;
            #     int n
            # ) -> result
            # blabla

            # blibli

            # pythran block (
            #     float[][][] a, b;
            #     int n
            # ) -> result
            result = np.zeros_like(a)
            for _ in range(n):
                result += a ** 2 + b ** 3

        a = result

        if fp.is_pythranized:
            result = fp.use_pythranized_block("block1")
        else:
            # pythran block (
            #     float[][] a, b;
            #     int n
            # ) -> (result, a)
            # blabla

            # blibli

            # pythran block (
            #     float[][][] a, b;
            #     int n
            # ) -> (result, a)
            result = np.zeros_like(a)
            for _ in range(n):
                result += a ** 2 + b ** 3

        return result


if __name__ == "__main__":

    shape = 100, 100
    a = np.random.rand(*shape)
    b = np.random.rand(*shape)

    obj = MyClass(a, b)

    obj.compute(10)

    if fp.is_pythranized:
        ret = obj.compute(10)
        fp.is_pythranized = False
        ret1 = obj.compute(10)
        fp.is_pythranized = True
        assert np.allclose(ret, ret1)
        print("allclose OK")

==> fluidpythran-0.1.5.tar.gz: fluidpythran-0.1.5/data_tests/class_blocks.py <==
import numpy as np

# pythran import numpy as np

# pythran blabla

from fluidpythran import FluidPythran

fp = FluidPythran()


class MyClass:
    def __init__(self, a, b):
        self.a = a
        self.b = b

    def compute(self, n):

        a = self.a
        b = self.b

        if fp.is_transpiled:
            result = fp.use_pythranized_block("block0")
        else:
            # pythran block (
            #     float[][] a, b;
            #     int n
            # ) -> result
            # blabla

            # blibli

            # pythran block (
            #     float[][][] a, b;
            #     int n
            # ) -> result
            result = np.zeros_like(a)
            for _ in range(n):
                result += a ** 2 + b ** 3

        a = result

        if fp.is_transpiled:
            result = fp.use_pythranized_block("block1")
        else:
            # pythran block (
            #     float[][] a, b;
            #     int n
            # ) -> (result)
            # blabla

            # blibli

            # pythran block (
            #     float[][][] a, b;
            #     int n
            # ) -> (result)
            result = np.zeros_like(a)
            for _ in range(n):
                result += a ** 2 + b ** 3

        return result


if __name__ == "__main__":

    shape = 2, 2
    a = np.random.rand(*shape)
    b = np.random.rand(*shape)

    obj = MyClass(a, b)

    ret0 = obj.compute(10)

    print("(is_transpiled, is_compiling, is_compiled)", (fp.is_transpiled, fp.is_compiling, fp.is_compiled))

    if fp.is_transpiled:
        ret = obj.compute(10)
        assert np.allclose(ret, ret0), (ret - ret0)
        fp.is_transpiled = False
        ret1 = obj.compute(10)
        fp.is_transpiled = True
        assert np.allclose(ret, ret1), (ret - ret1)
        print("allclose OK")
